@@ -1,21 +1,22 @@
+from __future__ import annotations
+
 import os
 import re
 import shutil
 import sys
 import urllib.request
 from pathlib import Path
-from typing import List, Optional, Union
+from typing import Optional
 
+from ._utils import tar_safe_extractall
 from ._version import SHINYLIVE_ASSETS_VERSION
 
 
 def download_shinylive(
-    destdir: Union[str, Path, None] = None,
+    destdir: str | Path | None = None,
     version: str = SHINYLIVE_ASSETS_VERSION,
     url: Optional[str] = None,
 ) -> None:
-    import tarfile
-
     if destdir is None:
         # Note that this is the cache directory, which is the parent of the assets
         # directory. The tarball will have the assets directory as the top-level subdir.
@@ -32,8 +33,7 @@ def download_shinylive(
         tmp_name, _ = urllib.request.urlretrieve(url)
 
         print(f"Unzipping to {destdir}/", file=sys.stderr)
-        with tarfile.open(tmp_name) as tar:
-            tar.extractall(destdir)
+        tar_safe_extractall(tmp_name, destdir)
     finally:
         if tmp_name is not None:
             Path(tmp_name).unlink(missing_ok=True)
@@ -74,8 +74,8 @@ def repodata_json_file(version: str = SHINYLIVE_ASSETS_VERSION) -> Path:
 
 
 def copy_shinylive_local(
-    source_dir: Union[str, Path],
-    destdir: Optional[Union[str, Path]] = None,
+    source_dir: str | Path,
+    destdir: Optional[str | Path] = None,
     version: str = SHINYLIVE_ASSETS_VERSION,
 ):
     if destdir is None:
@@ -96,8 +96,8 @@ def copy_shinylive_local(
 
 
 def link_shinylive_local(
-    source_dir: Union[str, Path],
-    destdir: Optional[Union[str, Path]] = None,
+    source_dir: str | Path,
+    destdir: Optional[str | Path] = None,
     version: str = SHINYLIVE_ASSETS_VERSION,
 ):
     if destdir is None:
@@ -120,7 +120,7 @@ def link_shinylive_local(
 
 
 def ensure_shinylive_assets(
-    destdir: Union[Path, None] = None,
+    destdir: Path | None = None,
     version: str = SHINYLIVE_ASSETS_VERSION,
     url: Optional[str] = None,
 ) -> Path:
@@ -145,7 +145,7 @@ def ensure_shinylive_assets(
 
 
 def cleanup_shinylive_assets(
-    shinylive_dir: Union[str, Path],
+    shinylive_dir: str | Path,
 ) -> None:
     """Removes local copies of shinylive web assets, except for the one used by the
     current version of the shinylive python package.
@@ -169,8 +169,8 @@ def cleanup_shinylive_assets(
 
 
 def remove_shinylive_assets(
-    shinylive_dir: Union[str, Path],
-    version: Union[str, List[str]],
+    shinylive_dir: str | Path,
+    version: str | list[str],
 ) -> None:
     """Removes local copy of shinylive.
 
@@ -208,7 +208,7 @@ def remove_shinylive_assets(
             print(f"{target_dir} does not exist.")
 
 
-def _installed_shinylive_versions(shinylive_dir: Optional[Path] = None) -> List[str]:
+def _installed_shinylive_versions(shinylive_dir: Optional[Path] = None) -> list[str]:
     if shinylive_dir is None:
         shinylive_dir = Path(shinylive_cache_dir())
 
